<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="da">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>Program_Name</source>
        <translation>Programnavn</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="46"/>
        <source>Quit application</source>
        <translation>Afslut programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="49"/>
        <source>Close</source>
        <translation>Luk</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="55"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Display help </source>
        <translation>Vis hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Help</source>
        <translation>Hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="96"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="112"/>
        <source>Back</source>
        <translation>Tilbage</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="169"/>
        <source>Next</source>
        <translation>Næste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>About this application</source>
        <translation>Om programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="203"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <source>View Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="253"/>
        <location filename="../mainwindow.cpp" line="507"/>
        <location filename="../mainwindow.cpp" line="530"/>
        <source>Select ISO</source>
        <translation>Vælg ISO</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="263"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select Target USB Device&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vælg mål-USB-enhed&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="273"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Select ISO file&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Vælg ISO-fil&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="289"/>
        <source>Advanced Options</source>
        <translation>Avancerede valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="307"/>
        <source>Make the ext4 filesystem even if one exists</source>
        <translation>Skab ext4-filsystemet, selv hvis der findes et</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <source>Save the original boot directory when updating a live-usb</source>
        <translation>Gem den originale opstartsmappe ved opdatering af en live-usb</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="321"/>
        <source>Use gpt partitioning instead of msdos</source>
        <translation>Brug gpt-partitionering i stedet for msdos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>GPT partitioning</source>
        <translation>GPT-partitionering</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="331"/>
        <source>Update (only update an existing live-usb)</source>
        <translation>Opdater (opdater kun et eksisterende live-usb)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="338"/>
        <source>Don&apos;t replace syslinux files</source>
        <translation>Erstat ikke syslinux-filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <source>Keep syslinux files</source>
        <translation>Bevar syslinux-filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="348"/>
        <source>Ignore USB/removable check</source>
        <translation>Ignorer tjek af USB/flytbar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="355"/>
        <source>Temporarily disable automounting</source>
        <translation>Deaktivér automatisk montering midlertidigt</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="365"/>
        <source>Set pmbr_boot disk flag (won&apos;t boot via UEFI)</source>
        <translation>Indstil pmbr_boot-diskflag (opstarter ikke via UEFI)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="372"/>
        <source>Don&apos;t use fuseiso to mount iso files</source>
        <translation>Brug ikke fuseiso til at montere iso-filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="398"/>
        <source>Size of ESP (uefi) partition:</source>
        <translation>Størrelse på ESP-partition (uefi):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Verbosity (less to more):</source>
        <translation>Uddybelse (mindre til mere):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="465"/>
        <source>vfat</source>
        <translation>vfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="506"/>
        <source>Data partition format type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="460"/>
        <source>exfat</source>
        <translation>exfat</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="470"/>
        <source>ext4</source>
        <translation>ext4</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="475"/>
        <source>ntfs</source>
        <translation>ntfs</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="499"/>
        <source>Make separate data partition (percent)</source>
        <translation>Skab separat datapartition (procent)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="516"/>
        <source>Refresh drive list</source>
        <translation>Genopfrisk drevliste</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="529"/>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Show advanced options</source>
        <translation>Vis avancerede valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="548"/>
        <source>Mode</source>
        <translation>Tilstand</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="563"/>
        <source>Full-featured mode - writable Li&amp;veUSB</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="573"/>
        <source>Read-only, cannot be used with persistency</source>
        <translation>Skrivebeskyttet, kan ikke bruges med vedvarenhed</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="576"/>
        <source>Image &amp;mode - read-only LiveUSB (dd)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="589"/>
        <source>For distros other than antiX/MX use image mode (dd).</source>
        <translation>Brug aftryk-tilstand (dd) til distroer som ikke er antiX/MX.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="637"/>
        <source>Options</source>
        <translation>Valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="675"/>
        <source>Percent of USB-device to use:</source>
        <translation>Procent af USB-enhed som der skal bruges:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="682"/>
        <source>Label ext partition:</source>
        <translation>Etiket til ext-partition:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="730"/>
        <source>Don&apos;t run commands that affect the usb device</source>
        <translation>Kør ikke kommandoer som påvirker usb-enheden</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="733"/>
        <source>Dry run (no change to system)</source>
        <translation>Tør kørsel (ingen ændring af systemet)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="740"/>
        <source>clone from a mounted live-usb or iso-file.</source>
        <translation>klon fra en monteret live-usb eller iso-file.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="743"/>
        <source>Clone a mounted live system</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="750"/>
        <source>Set up to boot from an encrypted partition, will prompt for pass phrase on first boot</source>
        <translation>Opsætning til opstart fra en krypterede partition, vil spørge om adgangskode ved første opstart.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="753"/>
        <source>Encrypt</source>
        <translation>Kryptér</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="760"/>
        <source>Clone running live system</source>
        <translation>Klon kørende livesystem</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="77"/>
        <source>Confirmation</source>
        <translation>Bekræftelse</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="78"/>
        <source>Target device %1 is larger than %2 GB. Do you wish to proceed?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <location filename="../mainwindow.cpp" line="461"/>
        <location filename="../mainwindow.cpp" line="629"/>
        <source>Failure</source>
        <translation>Mislykkedes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="113"/>
        <source>Source and destination are on the same device, please select again.</source>
        <translation>Kilde og destination er på den samme enhed, vælg venligst igen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Writing %1 using &apos;dd&apos; command to /dev/%2,

Please wait until the process is completed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="151"/>
        <source>MX Live Usb Maker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>Success</source>
        <translation>Det lykkedes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="327"/>
        <source>LiveUSB creation successful!</source>
        <translation>Oprettelse af LiveUSB lykkedes!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="330"/>
        <source>Error encountered in the LiveUSB creation process</source>
        <translation>Stødte på fejl i oprettelsesprocessen for LiveUSB</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="388"/>
        <source>Please select a USB device to write to</source>
        <translation>Vælg venligst et USB-enhed som der skal skrives til</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="391"/>
        <source>These actions will destroy all data on 

</source>
        <translation>Handlingerne vil ødelægge al data på 

</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="392"/>
        <source>Do you wish to continue?</source>
        <translation>Vil du fortsætte?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="424"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Version: </source>
        <translation>Version: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="427"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program til at oprette en live-usb fra en iso-fil, anden live-usb, en live-cd/-dvd, eller et kørende livesystem.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="430"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Ophavsret (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="431"/>
        <source>%1 License</source>
        <translation>%1-licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="438"/>
        <source>%1 Help</source>
        <translation>%1-hjælp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="446"/>
        <source>Select an ISO file to write to the USB drive</source>
        <translation>Vælg en ISO-fil som skal skrives til USB-drevet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>ISO Files (*.iso);;All Files (*.*)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="452"/>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Select Source Directory</source>
        <translation>Vælg kildemappe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="461"/>
        <source>Could not find linuxfs file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="476"/>
        <source>Hide advanced options</source>
        <translation>Skjul avancerede valgmuligheder</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>Select Source</source>
        <translation>Vælg kilde</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="506"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Select ISO file</source>
        <translation>Vælg ISO-fil</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="522"/>
        <source>clone</source>
        <translation>klon</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="589"/>
        <source>Could not find a log file at: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <location filename="../about.cpp" line="85"/>
        <source>Changelog</source>
        <translation>Ændringslog</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="76"/>
        <source>Cancel</source>
        <translation>Annuller</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="99"/>
        <source>&amp;Close</source>
        <translation>&amp;Luk</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="54"/>
        <source>Program for creating a live-usb from an iso-file, another live-usb, a live-cd/dvd, or a running live system.</source>
        <translation>Program til at oprette en live-usb fra en iso-fil, anden live-usb, en live-cd/-dvd, eller et kørende livesystem.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>filename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="58"/>
        <source>Name of .iso file to open</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="59"/>
        <source>[filename]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="87"/>
        <location filename="../main.cpp" line="96"/>
        <source>Error</source>
        <translation>Fejl</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="96"/>
        <source>You must run this program as root.</source>
        <translation>Du skal køre programmet som root.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="111"/>
        <source>version:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
